@@ -32,7 +32,9 @@ osi_NewVnode(void) {
     struct vcache *tvc;
 
     tvc = afs_osi_Alloc(sizeof(struct vcache));
-    osi_Assert(tvc != NULL);
+    if (tvc == NULL) {
+	return NULL;
+    }
 
 #ifdef	KERNEL_HAVE_PIN
     pin((char *)tvc, sizeof(struct vcache));	/* XXX */
