@@ -18,7 +18,9 @@ osi_NewVnode(void) {
     struct vcache *tvc;
 
     tvc = afs_osi_Alloc(sizeof(struct vcache));
-    osi_Assert(tvc != NULL);
+    if (tvc == NULL) {
+	return NULL;
+    }
     tvc->v = NULL; /* important to clean this, or use memset 0 */
 
     return tvc;
