@@ -19,7 +19,7 @@
 #endif
 
 /* From afs_util.c */
-extern afs_int32 afs_new_inum;
+extern afs_int32 afs_md5inum;
 
 /* From afs_analyze.c */
 extern afs_int32 hm_retry_RO;
@@ -38,125 +38,125 @@ static struct ctl_table afs_sysctl_table[] = {
     {
 #if defined(STRUCT_CTL_TABLE_HAS_CTL_NAME)
 #if defined(CTL_UNNUMBERED)
-	.ctl_name 	= CTL_UNNUMBERED, 
+	.ctl_name	= CTL_UNNUMBERED,
 #else
-	.ctl_name 	= 1, 
+	.ctl_name	= 1,
 #endif
 #endif
-	.procname 	= "hm_retry_RO",
-	.data 		= &hm_retry_RO, 
-	.maxlen		= sizeof(afs_int32), 
-	.mode     	= 0644,
+	.procname	= "hm_retry_RO",
+	.data		= &hm_retry_RO,
+	.maxlen		= sizeof(afs_int32),
+	.mode		= 0644,
 	.proc_handler	= &proc_dointvec
     },
     {
 #if defined(STRUCT_CTL_TABLE_HAS_CTL_NAME)
 #if defined(CTL_UNNUMBERED)
-	.ctl_name 	= CTL_UNNUMBERED, 
+	.ctl_name	= CTL_UNNUMBERED,
 #else
-        .ctl_name 	= 2, 
+	.ctl_name	= 2,
 #endif
 #endif
-        .procname 	= "hm_retry_RW",
-        .data		= &hm_retry_RW,
-	.maxlen		= sizeof(afs_int32), 
+	.procname	= "hm_retry_RW",
+	.data		= &hm_retry_RW,
+	.maxlen		= sizeof(afs_int32),
 	.mode		= 0644,
-     	.proc_handler	= &proc_dointvec
+	.proc_handler	= &proc_dointvec
     },
     {
 #if defined(STRUCT_CTL_TABLE_HAS_CTL_NAME)
 #if defined(CTL_UNNUMBERED)
-	.ctl_name 	= CTL_UNNUMBERED, 
+	.ctl_name	= CTL_UNNUMBERED,
 #else
-	.ctl_name	= 3, 
+	.ctl_name	= 3,
 #endif
 #endif
 	.procname	= "hm_retry_int",
-	.data		= &hm_retry_int, 
-	.maxlen		= sizeof(afs_int32), 
+	.data		= &hm_retry_int,
+	.maxlen		= sizeof(afs_int32),
 	.mode		= 0644,
 	.proc_handler	= &proc_dointvec
     },
     {
 #if defined(STRUCT_CTL_TABLE_HAS_CTL_NAME)
 #if defined(CTL_UNNUMBERED)
-	.ctl_name 	= CTL_UNNUMBERED, 
+	.ctl_name	= CTL_UNNUMBERED,
 #else
-	.ctl_name	= 4, 
+	.ctl_name	= 4,
 #endif
 #endif
 	.procname	= "GCPAGs",
-	.data		= &afs_gcpags, 
-	.maxlen		= sizeof(afs_int32), 
+	.data		= &afs_gcpags,
+	.maxlen		= sizeof(afs_int32),
 	.mode		= 0644,
-	.proc_handler 	= &proc_dointvec
+	.proc_handler	= &proc_dointvec
     },
     {
 #if defined(STRUCT_CTL_TABLE_HAS_CTL_NAME)
 #if defined(CTL_UNNUMBERED)
-	.ctl_name 	= CTL_UNNUMBERED, 
+	.ctl_name	= CTL_UNNUMBERED,
 #else
-	.ctl_name	= 5, 
+	.ctl_name	= 5,
 #endif
 #endif
 	.procname	= "rx_deadtime",
-	.data		= &afs_rx_deadtime, 
-	.maxlen		= sizeof(afs_int32), 
+	.data		= &afs_rx_deadtime,
+	.maxlen		= sizeof(afs_int32),
 	.mode		= 0644,
 	.proc_handler	= &proc_dointvec
     },
     {
 #if defined(STRUCT_CTL_TABLE_HAS_CTL_NAME)
 #if defined(CTL_UNNUMBERED)
-	.ctl_name 	= CTL_UNNUMBERED, 
+	.ctl_name	= CTL_UNNUMBERED,
 #else
-	.ctl_name	= 6, 
+	.ctl_name	= 6,
 #endif
 #endif
 	.procname	= "bkVolPref",
-	.data		= &afs_bkvolpref, 
-	.maxlen		= sizeof(afs_int32), 
+	.data		= &afs_bkvolpref,
+	.maxlen		= sizeof(afs_int32),
 	.mode		= 0644,
 	.proc_handler	= &proc_dointvec
     },
     {
 #if defined(STRUCT_CTL_TABLE_HAS_CTL_NAME)
 #if defined(CTL_UNNUMBERED)
-	.ctl_name 	= CTL_UNNUMBERED, 
+	.ctl_name	= CTL_UNNUMBERED,
 #else
-	.ctl_name	= 7, 
+	.ctl_name	= 7,
 #endif
 #endif
 	.procname	= "afs_blocksUsed",
 	.data		= &afs_blocksUsed,
-	.maxlen		= sizeof(afs_int32), 
+	.maxlen		= sizeof(afs_int32),
 	.mode		= 0444,
 	.proc_handler	= &proc_dointvec
     },
     {
 #if defined(STRUCT_CTL_TABLE_HAS_CTL_NAME)
 #if defined(CTL_UNNUMBERED)
-	.ctl_name 	= CTL_UNNUMBERED, 
+	.ctl_name	= CTL_UNNUMBERED,
 #else
-	.ctl_name	= 8, 
+	.ctl_name	= 8,
 #endif
 #endif
 	.procname	= "afs_blocksUsed_0",
 	.data		= &afs_blocksUsed_0,
 	.maxlen		= sizeof(afs_int32),
 	.mode		= 0644,
-     	.proc_handler	= &proc_dointvec
+	.proc_handler	= &proc_dointvec
     },
     {
 #if defined(STRUCT_CTL_TABLE_HAS_CTL_NAME)
 #if defined(CTL_UNNUMBERED)
-	.ctl_name 	= CTL_UNNUMBERED, 
+	.ctl_name	= CTL_UNNUMBERED,
 #else
-	.ctl_name	= 9, 
+	.ctl_name	= 9,
 #endif
 #endif
 	.procname	= "afs_blocksUsed_1",
-	.data		= &afs_blocksUsed_1, 
+	.data		= &afs_blocksUsed_1,
 	.maxlen		= sizeof(afs_int32),
 	.mode		= 0644,
 	.proc_handler	= &proc_dointvec
@@ -164,27 +164,27 @@ static struct ctl_table afs_sysctl_table[] = {
     {
 #if defined(STRUCT_CTL_TABLE_HAS_CTL_NAME)
 #if defined(CTL_UNNUMBERED)
-	.ctl_name 	= CTL_UNNUMBERED, 
+	.ctl_name	= CTL_UNNUMBERED,
 #else
-	.ctl_name	= 10, 
+	.ctl_name	= 10,
 #endif
 #endif
 	.procname	= "afs_blocksUsed_2",
-	.data		= &afs_blocksUsed_2, 
-	.maxlen		= sizeof(afs_int32), 
+	.data		= &afs_blocksUsed_2,
+	.maxlen		= sizeof(afs_int32),
 	.mode		= 0644,
 	.proc_handler	= &proc_dointvec
     },
     {
 #if defined(STRUCT_CTL_TABLE_HAS_CTL_NAME)
 #if defined(CTL_UNNUMBERED)
-	.ctl_name 	= CTL_UNNUMBERED, 
+	.ctl_name	= CTL_UNNUMBERED,
 #else
-	.ctl_name	= 11, 
+	.ctl_name	= 11,
 #endif
 #endif
 	.procname	= "afs_pct1",
-	.data		= &afs_pct1, 
+	.data		= &afs_pct1,
 	.maxlen		= sizeof(afs_int32),
 	.mode		= 0644,
 	.proc_handler	= &proc_dointvec
@@ -192,21 +192,21 @@ static struct ctl_table afs_sysctl_table[] = {
     {
 #if defined(STRUCT_CTL_TABLE_HAS_CTL_NAME)
 #if defined(CTL_UNNUMBERED)
-	.ctl_name 	= CTL_UNNUMBERED, 
+	.ctl_name	= CTL_UNNUMBERED,
 #else
-	.ctl_name	= 12, 
+	.ctl_name	= 12,
 #endif
 #endif
 	.procname	= "afs_pct2",
-	.data		= &afs_pct2, 
+	.data		= &afs_pct2,
 	.maxlen		= sizeof(afs_int32),
 	.mode		= 0644,
-     	.proc_handler   = &proc_dointvec
+	.proc_handler   = &proc_dointvec
     },
     {
 #if defined(STRUCT_CTL_TABLE_HAS_CTL_NAME)
 #if defined(CTL_UNNUMBERED)
-	.ctl_name 	= CTL_UNNUMBERED, 
+	.ctl_name	= CTL_UNNUMBERED,
 #else
 	.ctl_name	= 13,
 #endif
@@ -215,39 +215,43 @@ static struct ctl_table afs_sysctl_table[] = {
 	.data		= &afs_cacheBlocks,
 	.maxlen		= sizeof(afs_int32),
 	.mode		= 0644,
-    	.proc_handler	= &proc_dointvec
+	.proc_handler	= &proc_dointvec
     },
     {
 #if defined(STRUCT_CTL_TABLE_HAS_CTL_NAME)
 #if defined(CTL_UNNUMBERED)
-	.ctl_name 	= CTL_UNNUMBERED, 
+	.ctl_name	= CTL_UNNUMBERED,
 #else
-	.ctl_name	= 14, 
+	.ctl_name	= 14,
 #endif
 #endif
 	.procname	= "md5inum",
-	.data		= &afs_new_inum, 
+	.data		= &afs_md5inum,
 	.maxlen		= sizeof(afs_int32),
 	.mode		= 0644,
-     	.proc_handler	= &proc_dointvec
+	.proc_handler	= &proc_dointvec
     },
-    {0}
+    {
+	.procname	= 0
+    }
 };
 
 static struct ctl_table fs_sysctl_table[] = {
     {
 #if defined(STRUCT_CTL_TABLE_HAS_CTL_NAME)
 #if defined(CTL_UNNUMBERED)
-	.ctl_name 	= CTL_UNNUMBERED, 
+	.ctl_name	= CTL_UNNUMBERED,
 #else
-	.ctl_name	= 1, 
+	.ctl_name	= 1,
 #endif
 #endif
-	.procname	= "afs", 
-	.mode		= 0555, 
+	.procname	= "afs",
+	.mode		= 0555,
 	.child		= afs_sysctl_table
     },
-    {0}
+    {
+	.procname	= 0
+    }
 };
 
 int
