@@ -46,21 +46,11 @@ lockIdSet(struct AFS_FLOCK *flock, struct SimpleLocks *slp, int clid)
     proc_t *procp = ttoproc(curthread);
 
     if (slp) {
-# ifdef AFS_SUN53_ENV
 	slp->sysid = 0;
 	slp->pid = procp->p_pid;
-# else
-	slp->sysid = procp->p_sysid;
-	slp->pid = procp->p_epid;
-# endif
     } else {
-# ifdef AFS_SUN53_ENV
 	flock->l_sysid = 0;
 	flock->l_pid = procp->p_pid;
-# else
-	flock->l_sysid = procp->p_sysid;
-	flock->l_pid = procp->p_epid;
-# endif
     }
 }
 #elif defined(AFS_SGI_ENV)
@@ -132,7 +122,7 @@ lockIdSet(struct AFS_FLOCK *flock, struct SimpleLocks *slp, int clid)
 	flock->l_pid = clid;
     }
 }
-#elif defined(AFS_LINUX20_ENV) || defined(AFS_HPUX_ENV)
+#elif defined(AFS_LINUX_ENV) || defined(AFS_HPUX_ENV)
 void
 lockIdSet(struct AFS_FLOCK *flock, struct SimpleLocks *slp, int clid)
 {
@@ -183,7 +173,7 @@ lockIdcmp2(struct AFS_FLOCK *flock1, struct vcache *vp,
 #if	defined(AFS_SUN5_ENV)
     proc_t *procp = ttoproc(curthread);
 #else
-#if !defined(AFS_AIX41_ENV) && !defined(AFS_LINUX20_ENV) && !defined(AFS_SGI65_ENV) && !defined(AFS_DARWIN_ENV) && !defined(AFS_XBSD_ENV)
+#if !defined(AFS_AIX41_ENV) && !defined(AFS_LINUX_ENV) && !defined(AFS_SGI65_ENV) && !defined(AFS_DARWIN_ENV) && !defined(AFS_XBSD_ENV)
 #ifdef AFS_SGI64_ENV
     afs_proc_t *procp = curprocp;
 #elif defined(UKERNEL)
@@ -201,7 +191,7 @@ lockIdcmp2(struct AFS_FLOCK *flock1, struct vcache *vp,
 	}
 #endif
 	if ((flock1->l_pid == alp->pid) ||
-#if defined(AFS_AIX41_ENV) || defined(AFS_LINUX20_ENV) || defined(AFS_HPUX_ENV)
+#if defined(AFS_AIX41_ENV) || defined(AFS_LINUX_ENV) || defined(AFS_HPUX_ENV)
 	    (!onlymine && (flock1->l_pid == getppid()))
 #else
 #if defined(AFS_SGI65_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
@@ -335,7 +325,7 @@ HandleFlock(struct vcache *avc, int acom, struct vrequest *areq,
 	    if (!AFS_IS_DISCONNECTED) {
 		struct rx_connection *rxconn;
 	        do {
-		  tc = afs_Conn(&avc->f.fid, areq, SHARED_LOCK, &rxconn);
+		    tc = afs_Conn(&avc->f.fid, areq, SHARED_LOCK, &rxconn);
 		    if (tc) {
 		        XSTATS_START_TIME(AFS_STATS_FS_RPCIDX_RELEASELOCK);
 		        RX_AFS_GUNLOCK();
@@ -391,8 +381,8 @@ HandleFlock(struct vcache *avc, int acom, struct vrequest *areq,
 		    }
 		}
 		if (!code && avc->flockCount == 0) {
-		    struct rx_connection *rxconn;
 		    if (!AFS_IS_DISCONNECTED) {
+			struct rx_connection *rxconn;
 		        do {
 			    tc = afs_Conn(&avc->f.fid, areq, SHARED_LOCK, &rxconn);
 			    if (tc) {
@@ -404,7 +394,7 @@ HandleFlock(struct vcache *avc, int acom, struct vrequest *areq,
 						      (struct AFSFid *)&avc->
 						      f.fid.Fid, &tsync);
 			        RX_AFS_GLOCK();
-				XSTATS_END_TIME;
+			       XSTATS_END_TIME;
 			    } else
 			        code = -1;
 		        } while (afs_Analyze
@@ -551,7 +541,7 @@ DoLockWarning(struct vcache *avc, afs_ucred_t * acred)
     lastWarnTime = avc->lastBRLWarnTime = now;
     lastWarnPid = pid;
 
-#ifdef AFS_LINUX26_ENV
+#ifdef AFS_LINUX_ENV
     message = "byte-range locks only enforced for processes on this machine";
 #else
     message = "byte-range lock/unlock ignored; make sure no one else is running this program";
@@ -591,7 +581,7 @@ int afs_lockctl(struct vcache * avc, struct AFS_FLOCK * af, int acmd,
     if (code) {
 	goto done;
     }
-#if (defined(AFS_SGI_ENV) || defined(AFS_SUN5_ENV)) && !defined(AFS_SUN58_ENV)
+#if defined(AFS_SGI_ENV)
     if ((acmd == F_GETLK) || (acmd == F_RGETLK)) {
 #else
     if (acmd == F_GETLK) {
@@ -604,7 +594,7 @@ int afs_lockctl(struct vcache * avc, struct AFS_FLOCK * af, int acmd,
 	code = afs_CheckCode(code, treq, 2);	/* defeat buggy AIX optimz */
 	goto done;
     } else if ((acmd == F_SETLK) || (acmd == F_SETLKW)
-#if (defined(AFS_SGI_ENV) || defined(AFS_SUN5_ENV)) && !defined(AFS_SUN58_ENV)
+#if defined(AFS_SGI_ENV)
 	       || (acmd == F_RSETLK) || (acmd == F_RSETLKW)) {
 #else
 	) {
@@ -643,7 +633,7 @@ int afs_lockctl(struct vcache * avc, struct AFS_FLOCK * af, int acmd,
 	goto done;
     }
     if (((acmd == F_SETLK)
-#if 	(defined(AFS_SGI_ENV) || defined(AFS_SUN5_ENV)) && !defined(AFS_SUN58_ENV)
+#if 	defined(AFS_SGI_ENV)
 	 || (acmd == F_RSETLK)
 #endif
 	) && code != LOCK_UN)
