@@ -46,7 +46,6 @@ afs_read(struct vcache *avc, struct uio *auio, afs_ucred_t *acred,
 	 int noLock)
 {
     afs_size_t totalLength;
-    afs_size_t transferLength;
     afs_size_t filePos;
     afs_size_t offset, tlen;
     afs_size_t len = 0;
@@ -96,7 +95,6 @@ afs_read(struct vcache *avc, struct uio *auio, afs_ucred_t *acred,
 	       totalLength, ICL_TYPE_OFFSET,
 	       ICL_HANDLE_OFFSET(avc->f.m.Length));
     error = 0;
-    transferLength = 0;
     if (!noLock)
 	ObtainReadLock(&avc->lock);
 #if	defined(AFS_TEXT_ENV) && !defined(AFS_VM_RDWR_ENV)
@@ -190,7 +188,7 @@ afs_read(struct vcache *avc, struct uio *auio, afs_ucred_t *acred,
 	     * 2 requests never return a null dcache entry, btw.
 	     */
 	    if (!(tdc->dflags & DFFetching)
-		&& !hsame(avc->f.m.DataVersion, tdc->f.versionNo)) {
+		&& !afs_IsDCacheFresh(tdc, avc)) {
 		/* have cache entry, it is not coming in now,
 		 * and we'll need new data */
 	      tagain:
@@ -270,7 +268,7 @@ afs_read(struct vcache *avc, struct uio *auio, afs_ucred_t *acred,
 	    } else {
 		/* no longer fetching, verify data version 
 		 * (avoid new GetDCache call) */
-		if (hsame(avc->f.m.DataVersion, tdc->f.versionNo)
+		if (afs_IsDCacheFresh(tdc, avc)
 		    && ((len = tdc->validPos - filePos) > 0)) {
 		    offset = filePos - AFS_CHUNKTOBASE(tdc->f.chunk);
 		} else {
@@ -352,7 +350,6 @@ afs_read(struct vcache *avc, struct uio *auio, afs_ucred_t *acred,
 	trimlen = len;
 	afsio_skip(auio, trimlen);	/* update input uio structure */
 	totalLength -= len;
-	transferLength += len;
 	filePos += len;
 
 	if (len <= 0)
@@ -548,7 +545,7 @@ afs_UFSReadUIO(afs_dcache_id_t *cacheId, struct uio *tuiop)
     AFS_GUNLOCK();
     code = VOP_RDWR(tfile->vnode, tuiop, UIO_READ, 0, afs_osi_credp);
     AFS_GLOCK();
-#elif defined(AFS_LINUX20_ENV)
+#elif defined(AFS_LINUX_ENV)
     AFS_GUNLOCK();
     code = osi_rdwr(tfile, tuiop, UIO_READ);
     AFS_GLOCK();
