@@ -21,6 +21,9 @@
 #include "afsincludes.h"	/*AFS-based standard headers */
 #include "afs/afs_stats.h"	/*Cache Manager stats */
 #include "afs/afs_args.h"
+#if defined(UKERNEL)
+# include "roken.h"
+#endif
 
 afs_int32 afs_allCBs = 0;	/*Break callbacks on all objects */
 afs_int32 afs_oddCBs = 0;	/*Break callbacks on dirs */
@@ -66,7 +69,7 @@ static struct ltable {
 };
 unsigned long lastCallBack_vnode;
 unsigned int lastCallBack_dv;
-osi_timeval_t lastCallBack_time;
+osi_timeval32_t lastCallBack_time;
 
 /* these are for storing alternate interface addresses */
 struct interfaceAddr afs_cb_interface;
@@ -311,7 +314,7 @@ SRXAFSCB_GetLock(struct rx_call *a_call, afs_int32 a_index,
 	code = 1;
     } else if (a_index >= nentries) {
 	struct cell *tc = afs_GetCellByIndex(a_index-nentries, 0);
-	strcpy(a_result->name, tc->cellName);
+	strlcpy(a_result->name, tc->cellName, sizeof(a_result->name));
 	a_result->lock.waitStates =
 	    ((struct afs_lock *)&(tc->lock))->wait_states;
 	a_result->lock.exclLocked =
@@ -338,7 +341,7 @@ SRXAFSCB_GetLock(struct rx_call *a_call, afs_int32 a_index,
 	 * Found it - copy out its contents.
 	 */
 	tl = &ltable[a_index];
-	strcpy(a_result->name, tl->name);
+	strlcpy(a_result->name, tl->name, sizeof(a_result->name));
 	a_result->lock.waitStates =
 	    ((struct afs_lock *)(tl->addr))->wait_states;
 	a_result->lock.exclLocked =
