@@ -1913,91 +1913,6 @@ FindClone(struct rx_call *call, afs_int32 dumpID, char *volName,
     return (code);
 }
 
-#ifdef notdef
-/*
- *      Searches each tape and each volume in the dump until the volume is found.
- *      If the volume is not in the dump, then we search it's parent dump.
- *
- *	Re-write to do lookups by volume name.
- */
-afs_int32
-FindClone(struct rx_call *call, afs_int32 dumpID, char *volName,
-	  afs_int32 *clonetime)
-{
-    struct ubik_trans *ut;
-    dbadr diskAddr, tapeAddr, volFragmentAddr;
-    struct dump dump;
-    struct tape tape;
-    struct volFragment volFragment;
-    struct volInfo volInfo;
-    afs_int32 eval, code = 0;
-
-    if (!callPermitted(call))
-	return BUDB_NOTPERMITTED;
-
-    eval = InitRPC(&ut, LOCKREAD, 1);
-    if (eval)
-	return (eval);
-
-    *clonetime = 0;
-
-    for (; dumpID; dumpID = ntohl(dump.parent)) {	/*d */
-	/* Get the dump entry */
-	eval = ht_LookupEntry(ut, &db.dumpIden, &dumpID, &diskAddr, &dump);
-	if (eval)
-	    ABORT(eval);
-	if (!diskAddr)
-	    ABORT(BUDB_NODUMPID);
-
-	/* just to be sure */
-	if (ntohl(dump.id) != dumpID) {
-	    LogDebug(4, "BUDB_FindClone: requested %d, found %d\n", dumpID,
-		     ntohl(dump.id));
-	    ABORT(BUDB_INTERNALERROR);
-	}
-
-	/* search all the tapes in this dump */
-	for (tapeAddr = ntohl(dump.firstTape); tapeAddr; tapeAddr = ntohl(tape.nextTape)) {	/*t */
-	    /* Get the tape entry */
-	    eval = dbread(ut, tapeAddr, &tape, sizeof(tape));
-	    if (eval)
-		ABORT(eval);
-
-	    /* search all the volume fragments on this tape */
-	    for (volFragmentAddr = ntohl(tape.firstVol); volFragmentAddr; volFragmentAddr = ntohl(volFragment.sameTapeChain)) {	/*vf */
-		/* Get the volume fragment entry */
-		eval =
-		    dbread(ut, volFragmentAddr, &volFragment,
-			   sizeof(volFragment));
-		if (eval)
-		    ABORT(eval);
-
-		/* Get the volume info entry */
-		eval =
-		    dbread(ut, ntohl(volFragment.vol), &volInfo,
-			   sizeof(volInfo));
-		if (eval)
-		    ABORT(eval);
-
-		/* check if this volume is the one we want */
-		if (strcmp(volInfo.name, volName) == 0) {
-		    *clonetime = ntohl(volFragment.clone);
-		    ERROR(0);
-		}
-	    }			/*vf */
-	}			/*t */
-    }				/*d */
-
-  error_exit:
-    code = ubik_EndTrans(ut);
-    return (code);
-
-  abort_exit:
-    ubik_EndTrans(ut);
-    return (code);
-}
-#endif
-
 /* BUDB_FindDump
  *      Find latest volume dump before adate.
  *      Used by restore code when restoring a user requested volume(s)
@@ -2230,7 +2145,9 @@ FindLatestDump(struct rx_call *call, char *vsname, char *dumpPath,
 
   finished:
     /* return the dump found */
-    FillDumpEntry(ut, retdbaddr, dumpentry);
+    eval = FillDumpEntry(ut, retdbaddr, dumpentry);
+    if (eval)
+	ABORT(eval);
 
     code = ubik_EndTrans(ut);
     return (code);
@@ -3691,86 +3608,6 @@ volFragsDump(struct ubik_trans *ut, FILE *dumpfid, dbadr dbAddr)
     return (0);
 }
 
-#ifdef notdef
-/* utilities - network to host conversion
- *	currently used for debug only
- */
-
-void
-volFragmentDiskToHost(struct volFragment *diskVfPtr,
-		      struct volFragment *hostVfPtr)
-{
-    hostVfPtr->vol = ntohl(diskVfPtr->vol);
-    hostVfPtr->sameNameChain = ntohl(diskVfPtr->sameNameChain);
-    hostVfPtr->tape = ntohl(diskVfPtr->tape);
-    hostVfPtr->sameTapeChain = ntohl(diskVfPtr->sameTapeChain);
-    hostVfPtr->position = ntohl(diskVfPtr->position);
-    hostVfPtr->clone = ntohl(diskVfPtr->clone);
-    hostVfPtr->incTime = ntohl(diskVfPtr->incTime);
-    hostVfPtr->startByte = ntohl(diskVfPtr->startByte);
-    hostVfPtr->nBytes = ntohl(diskVfPtr->nBytes);
-    hostVfPtr->flags = ntohs(diskVfPtr->flags);
-    hostVfPtr->sequence = ntohs(diskVfPtr->sequence);
-}
-
-void
-volInfoDiskToHost(struct volInfo *diskViPtr, struct volInfo *hostViPtr)
-{
-    strcpy(hostViPtr->name, diskViPtr->name);
-    hostViPtr->nameHashChain = ntohl(diskViPtr->nameHashChain);
-    hostViPtr->id = ntohl(diskViPtr->id);
-    strcpy(hostViPtr->server, diskViPtr->server);
-    hostViPtr->partition = ntohl(diskViPtr->partition);
-    hostViPtr->flags = ntohl(diskViPtr->flags);
-    hostViPtr->sameNameHead = ntohl(diskViPtr->sameNameHead);
-    hostViPtr->sameNameChain = ntohl(diskViPtr->sameNameChain);
-    hostViPtr->firstFragment = ntohl(diskViPtr->firstFragment);
-    hostViPtr->nFrags = ntohl(diskViPtr->nFrags);
-}
-
-void
-tapeDiskToHost(struct tape *diskTapePtr, struct tape *hostTapePtr)
-{
-    strcpy(hostTapePtr->name, diskTapePtr->name);
-    hostTapePtr->nameHashChain = ntohl(diskTapePtr->nameHashChain);
-    hostTapePtr->flags = ntohl(diskTapePtr->flags);
-
-    /* tape id conversion here */
-    hostTapePtr->written = ntohl(diskTapePtr->written);
-    hostTapePtr->nBytes = ntohl(diskTapePtr->nBytes);
-    hostTapePtr->nFiles = ntohl(diskTapePtr->nFiles);
-    hostTapePtr->nVolumes = ntohl(diskTapePtr->nVolumes);
-    hostTapePtr->seq = ntohl(diskTapePtr->seq);
-    hostTapePtr->dump = ntohl(diskTapePtr->dump);
-    hostTapePtr->nextTape = ntohl(diskTapePtr->nextTape);
-    hostTapePtr->firstVol = ntohl(diskTapePtr->firstVol);
-    hostTapePtr->useCount = ntohl(diskTapePtr->useCount);
-}
-
-void
-dumpDiskToHost(struct dump *diskDumpPtr, struct dump *hostDumpPtr)
-{
-    hostDumpPtr->id = ntohl(diskDumpPtr->id);
-    hostDumpPtr->idHashChain = ntohl(diskDumpPtr->idHashChain);
-    strcpy(hostDumpPtr->dumpName, diskDumpPtr->dumpName);
-    strcpy(hostDumpPtr->dumpPath, diskDumpPtr->dumpPath);
-    strcpy(hostDumpPtr->volumeSet, diskDumpPtr->volumeSet);
-    hostDumpPtr->nameHashChain = ntohl(diskDumpPtr->nameHashChain);
-    hostDumpPtr->flags = ntohl(diskDumpPtr->flags);
-    hostDumpPtr->parent = ntohl(diskDumpPtr->parent);
-    hostDumpPtr->created = ntohl(diskDumpPtr->created);
-/*  hostDumpPtr->incTime = ntohl(diskDumpPtr->incTime); */
-    hostDumpPtr->nVolumes = ntohl(diskDumpPtr->nVolumes);
-
-    /* tapeset conversion here */
-
-    hostDumpPtr->firstTape = ntohl(diskDumpPtr->firstTape);
-
-    /* principal conversion here */
-}
-
-#endif /* notdef */
-
 int
 checkHash(struct ubik_trans *ut, int hashType)
 {
