@@ -10,26 +10,13 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-#include <sys/types.h>
-#ifdef AFS_NT40_ENV
-#include <winsock2.h>
-#else
-#include <sys/time.h>
-#include <sys/file.h>
-#include <netinet/in.h>
-#include <sys/socket.h>
-#include <netdb.h>
-#endif
-#include <stdlib.h>
-#include <string.h>
-#ifdef HAVE_STDINT_H
-# include <stdint.h>
-#endif
+#include <roken.h>
+
+#include <afs/opr.h>
 #include <rx/xdr.h>
 #include <rx/rx.h>
 #include <lwp.h>
 #include <lock.h>
-#include <errno.h>
 #include <afs/tcdata.h>
 #include <afs/bubasics.h>
 #include <afs/budb_client.h>
@@ -37,6 +24,7 @@
 #include <afs/vldbint.h>
 #include <afs/ktime.h>
 #include <afs/vlserver.h>
+#include <afs/afsint.h>
 #include <afs/volser.h>
 #include <afs/volser_prototypes.h>
 #include <afs/volint.h>
@@ -55,8 +43,7 @@ extern int isafile;
 extern int forcemultiple;
 
 extern struct ubik_client *cstruct;
-dlqlinkT savedEntries;
-dlqlinkT entries_to_flush;
+extern dlqlinkT savedEntries;
 
 extern afs_int32 groupId;
 extern afs_int32 BufferSize;
@@ -74,8 +61,8 @@ extern char *xbsalGName;
 extern char *globalButcLog;
 #endif /*xbsa */
 
-afs_int32 dataSize;		/* Size of data to read on each rx_Read() call */
-afs_int32 tapeblocks;		/* Number of 16K tape datablocks in buffer (!CONF_XBSA) */
+extern afs_int32 dataSize;		/* Size of data to read on each rx_Read() call */
+extern afs_int32 tapeblocks;		/* Number of 16K tape datablocks in buffer (!CONF_XBSA) */
 
 /* TBD
  *
@@ -94,21 +81,6 @@ afs_int32 tapeblocks;		/* Number of 16K tape datablocks in buffer (!CONF_XBSA) *
  *	least something usable.
  */
 
-#define DUMPNAME(dumpname, name, dbDumpId) \
-   if (dbDumpId == 0) \
-     sprintf(dumpname, "%s", name); \
-   else \
-     sprintf(dumpname, "%s (DumpId %u)", name, dbDumpId);
-
-#if defined(AFS_NT40_ENV) || defined(AFS_SUN4_ENV)
-int
-localtime_r(time_t * t, struct tm *tm)
-{
-    memcpy(tm, localtime(t), sizeof(struct tm));
-    return 0;
-}
-#endif
-
 struct dumpRock {
     /* status only */
     int tapeSeq;
@@ -319,8 +291,6 @@ dumpVolume(struct tc_dumpDesc * curDump, struct dumpRock * dparamsPtr)
 	chunkSize = 0;
 	fragmentvolume = 0;
 	while (!endofvolume && !fragmentvolume) {	/*w */
-	    bytesread = 0;
-
 	    /* Check for abort in the middle of writing data */
 	    if (volBytesRead >= chunkSize) {
 		chunkSize += BIGCHUNK;
@@ -562,7 +532,6 @@ xbsaDumpVolume(struct tc_dumpDesc * curDump, struct dumpRock * dparamsPtr)
     afs_uint32 statuscount = statusSize, tsize = 0, esize;
     afs_hyper_t estSize;
 
-    char dumpIdStr[XBSA_MAX_OSNAME];
     char volumeNameStr[XBSA_MAX_PATHNAME];
     static char *dumpDescription = "AFS volume dump";
     static char *objectDescription = "XBSA - butc";
@@ -622,14 +591,12 @@ xbsaDumpVolume(struct tc_dumpDesc * curDump, struct dumpRock * dparamsPtr)
     dparamsPtr->curVolStartPos = tapeInfoPtr->position;
 
     /* Tell XBSA what the name and size of volume to write */
-    strcpy(dumpIdStr, butcdumpIdStr);	/* "backup_afs_volume_dumps" */
-    sprintf(volumeNameStr, "/%d", dparamsPtr->databaseDumpId);
-    strcat(volumeNameStr, "/");
-    strcat(volumeNameStr, curDump->name);	/* <dumpid>/<volname> */
+    snprintf(volumeNameStr, sizeof(volumeNameStr), "/%d/%s",
+	     dparamsPtr->databaseDumpId, curDump->name);
     hset32(estSize, esize);
     hshlft(estSize, 10);	/* Multiply by 1024 so its in KB */
 
-    rc = xbsa_WriteObjectBegin(&butxInfo, dumpIdStr, volumeNameStr,
+    rc = xbsa_WriteObjectBegin(&butxInfo, butcdumpIdStr, volumeNameStr,
 			       xbsalGName, estSize, dumpDescription,
 			       objectDescription);
     if (rc != XBSA_SUCCESS) {
@@ -671,8 +638,6 @@ xbsaDumpVolume(struct tc_dumpDesc * curDump, struct dumpRock * dparamsPtr)
     volBytesRead = 0;
     chunkSize = 0;
     while (!endofvolume) {	/*w */
-	bytesread = 0;
-
 	/* Check for abort in the middle of writing data */
 	if (volBytesRead >= chunkSize) {
 	    chunkSize += BIGCHUNK;
@@ -895,7 +860,7 @@ dumpPass(struct dumpRock * dparamsPtr, int passNumber)
 
 	    switch (curDump->vtype) {
 	    case BACKVOL:
-		if (!(vldbEntry.flags & BACK_EXISTS)) {
+		if (!(vldbEntry.flags & VLF_BACKEXISTS)) {
 		    ErrorLog(0, taskId, 0, 0,
 			     "Volume %s (%u) failed - Backup volume no longer exists\n",
 			     curDump->name, curDump->vid);
@@ -903,11 +868,10 @@ dumpPass(struct dumpRock * dparamsPtr, int passNumber)
 		    dparamsPtr->volumesFailed++;
 		    continue;
 		}
-		/* Fall into RWVOL case */
-
+		AFS_FALLTHROUGH;
 	    case RWVOL:
 		for (e = 0; e < vldbEntry.nServers; e++) {	/* Find the RW volume */
-		    if (vldbEntry.serverFlags[e] & ITSRWVOL)
+		    if (vldbEntry.serverFlags[e] & VLSF_RWVOL)
 			break;
 		}
 		break;
@@ -925,7 +889,7 @@ dumpPass(struct dumpRock * dparamsPtr, int passNumber)
 
 		if (e >= vldbEntry.nServers) {	/* Didn't find RO volume */
 		    for (e = 0; e < vldbEntry.nServers; e++) {	/* Find the first RO volume */
-			if (vldbEntry.serverFlags[e] & ITSROVOL)
+			if (vldbEntry.serverFlags[e] & VLSF_ROVOL)
 			    break;
 		    }
 		}
@@ -1141,9 +1105,9 @@ Dumper(void *param)
     int dumpedvolumes = 0;
     int nodumpvolumes = 0;
     char strlevel[5];
-    char msg[20];
-    char finishedMsg1[50];
-    char finishedMsg2[50];
+    char msg[128];
+    char finishedMsg1[128];
+    char finishedMsg2[128];
     time_t startTime = 0;
     time_t endTime = 0;
     afs_int32 allocbufferSize;
@@ -1151,6 +1115,7 @@ Dumper(void *param)
     extern struct deviceSyncNode *deviceLatch;
     extern struct tapeConfig globalTapeConfig;
 
+    opr_threadname_set("dumper");
     taskId = nodePtr->taskID;	/* Get task Id */
     setStatus(taskId, DRIVE_WAIT);
     EnterDeviceQueue(deviceLatch);
@@ -1211,7 +1176,7 @@ Dumper(void *param)
      * Used when requesting a tape. Done now because once we create the dump, the
      * routine will then find the newly created dump.
      */
-    sprintf(strlevel, "%d", nodePtr->level);
+    snprintf(strlevel, sizeof(strlevel), "%d", nodePtr->level);
     code =
 	bcdb_FindLatestDump(nodePtr->volumeSetName, strlevel,
 			    &dparams.lastDump);
@@ -1316,15 +1281,21 @@ Dumper(void *param)
 
     lastPass = 1;		/* In case we aborted */
 
-    DUMPNAME(finishedMsg1, nodePtr->dumpSetName, dparams.databaseDumpId);
-    sprintf(finishedMsg2, "%d volumes dumped", dumpedvolumes);
+    /* Format and log finished message. */
+    snprintf(finishedMsg1, sizeof(finishedMsg1), "%s", nodePtr->dumpSetName);
+    if (dparams.databaseDumpId != 0) {
+	snprintf(msg, sizeof(msg), " (DumpId %u)", dparams.databaseDumpId);
+	strlcat(finishedMsg1, msg, sizeof(finishedMsg1));
+    }
+    snprintf(finishedMsg2, sizeof(finishedMsg2),
+	     "%d volumes dumped", dumpedvolumes);
     if (failedvolumes) {
-	sprintf(msg, ", %d failed", failedvolumes);
-	strcat(finishedMsg2, msg);
+	snprintf(msg, sizeof(msg), ", %d failed", failedvolumes);
+	strlcat(finishedMsg2, msg, sizeof(finishedMsg2));
     }
     if (nodumpvolumes) {
-	sprintf(msg, ", %d unchanged", nodumpvolumes);
-	strcat(finishedMsg2, msg);
+	snprintf(msg, sizeof(msg), ", %d unchanged", nodumpvolumes);
+	strlcat(finishedMsg2, msg, sizeof(finishedMsg2));
     }
 
     if (code == TC_ABORTEDBYREQUEST) {
@@ -1345,7 +1316,7 @@ Dumper(void *param)
     if (centralLogIO && startTime) {
 	long timediff;
 	afs_int32 hrs, min, sec, tmp;
-	char line[1024];
+	char *line = NULL;
 	struct tm tmstart, tmend;
 
 	localtime_r(&startTime, &tmstart);
@@ -1356,7 +1327,7 @@ Dumper(void *param)
 	min = tmp / 60;
 	sec = tmp % 60;
 
-	sprintf(line,
+	code = asprintf(&line,
 		"%-5d  %02d/%02d/%04d %02d:%02d:%02d  "
 		"%02d/%02d/%04d %02d:%02d:%02d  " "%02d:%02d:%02d  "
 		"%s %d of %d volumes dumped (%lu KB)\n", taskId,
@@ -1367,9 +1338,13 @@ Dumper(void *param)
 		nodePtr->volumeSetName, dumpedvolumes,
 		dumpedvolumes + failedvolumes,
 		afs_printable_uint32_lu(dparams.tapeInfoPtr->kBytes + 1));
-
-	fwrite(line, strlen(line), 1, centralLogIO);
-	fflush(centralLogIO);
+	if (code < 0)
+	    line = NULL;
+	if (line != NULL) {
+	    fwrite(line, strlen(line), 1, centralLogIO);
+	    fflush(centralLogIO);
+	}
+	free(line);
     }
 
     setStatus(taskId, TASK_DONE);
@@ -1417,11 +1392,7 @@ retryPrompt(char *volumeName, afs_int32 volumeId, afs_uint32 taskId)
 
 	start = time(0);
 	while (1) {
-#ifdef AFS_PTHREAD_ENV
-	    code = GetResponseKey(5, &ch);	/* ch stores key pressed */
-#else
 	    code = LWP_GetResponseKey(5, &ch);	/* ch stores key pressed */
-#endif
 	    if (code == 1)
 		break;		/* input is available */
 
@@ -1723,7 +1694,7 @@ getDumpTape(struct dumpRock *dparamsPtr, int interactiveFlag,
 			code = bcdb_FindDumpByID(dmp, &de);
 			if (code)
 			    break;
-			sprintf(strlevel, "%d", de.level);
+			snprintf(strlevel, sizeof(strlevel), "%d", de.level);
 			code =
 			    bcdb_FindLatestDump(de.volumeSetName, strlevel,
 						&de2);
@@ -2061,6 +2032,7 @@ DeleteDump(void *param)
     dumpid = ptr->dumpID;
     taskId = ptr->taskId;	/* Get task Id */
 
+    opr_threadname_set("deletedump");
     setStatus(taskId, DRIVE_WAIT);
     EnterDeviceQueue(deviceLatch);
     clearStatus(taskId, DRIVE_WAIT);
@@ -2156,15 +2128,14 @@ DeleteDump(void *param)
 	for (i = 0; i < vl.budb_volumeList_len; i++) {
 	    if (dumpEntry.flags & BUDB_DUMP_BUTA) {
 		/* dump was from buta, use old buta style names */
-		sprintf(dumpIdStr, "/%d", dumpid);
-		strcpy(volumeNameStr, "/");
-		strcat(volumeNameStr, (char *)vl.budb_volumeList_val[i].name);
+		snprintf(dumpIdStr, sizeof(dumpIdStr), "/%d", dumpid);
+		snprintf(volumeNameStr, sizeof(volumeNameStr), "/%s",
+			 (char *)vl.budb_volumeList_val[i].name);
 	    } else {		/* BUDB_DUMP_ADSM */
 		/* dump was from butc to ADSM, use butc names */
-		strcpy(dumpIdStr, butcdumpIdStr);
-		sprintf(volumeNameStr, "/%d", dumpid);
-		strcat(volumeNameStr, "/");
-		strcat(volumeNameStr, (char *)vl.budb_volumeList_val[i].name);
+		snprintf(dumpIdStr, sizeof(dumpIdStr), "%s", butcdumpIdStr);
+		snprintf(volumeNameStr, sizeof(volumeNameStr), "/%d/%s",
+			 dumpid, (char *)vl.budb_volumeList_val[i].name);
 	    }
 
 	    rc = xbsa_DeleteObject(&butxInfo, dumpIdStr, volumeNameStr);
