@@ -20,7 +20,6 @@
 #define AFS_AIX51_ENV		1
 #define AFS_AIX52_ENV		1
 
-#define AFS_64BIT_ENV		1
 #define AFS_64BIT_CLIENT	1
 #define AFS_NAMEI_ENV		1
 #ifdef AFS_NAMEI_ENV
@@ -60,7 +59,6 @@
 
 /* Extra kernel definitions (from kdefs file) */
 #ifdef _KERNEL
-#define	AFS_SHORTGID	1
 #define	AFS_UIOFMODE	1
 #define	afsio_iov	uio_iov
 #define	afsio_iovcnt	uio_iovcnt
@@ -72,7 +70,6 @@
 #define	AFS_UIOUSER	UIO_USERSPACE
 #define	AFS_CLBYTES	CLBYTES
 #define	AFS_MINCHANGE	2
-#define osi_GetTime(x)          do {curtime(x); (x)->tv_usec = (x)->tv_usec/1000;} while (0)
 #define	osi_GTime(x)	time	/* something for the silly time(0)?? */
 #define	AFS_KALLOC	kmem_alloc
 #define	AFS_KFREE	kmem_free
@@ -98,7 +95,6 @@
 #ifndef	AFS_PARAM_H
 #define	AFS_PARAM_H
 
-#define AFS_64BIT_ENV           1
 #define AFS_64BIT_CLIENT        1
 #define AFS_NAMEI_ENV           1
 #ifdef AFS_NAMEI_ENV
