@@ -5,7 +5,6 @@
 #define AFS_PARAM_H
 
 #define AFS_ENV                 1
-#define AFS_64BIT_ENV           1	/* Defines afs_int32 as int, not long. */
 #define AFS_64BIT_CLIENT        1
 #define AFS_64BIT_IOPS_ENV	1
 #if defined(__ppc__)
@@ -34,6 +33,7 @@
 #define DARWIN_REFBASE 3
 #define AFS_WARNUSER_MARINER_ENV 1
 #define AFS_CACHE_VNODE_PATH
+#define AFS_NEW_BKG 1
 #define NEED_IOCTL32
 
 /* File system entry (used if mount.h doesn't define MOUNT_AFS */
@@ -113,7 +113,6 @@
 #define AFS_UIOSYS      UIO_SYSSPACE
 #define AFS_UIOUSER     UIO_USERSPACE
 #define AFS_CLBYTES     CLBYTES
-#define osi_GetTime(x)  microtime(x)
 #define AFS_KALLOC(x)   _MALLOC(x, M_TEMP, M_WAITOK)
 #define AFS_KFREE(x,y)  _FREE(x,M_TEMP)
 #define v_count         v_usecount
@@ -138,6 +137,7 @@
 
 #define AFS_VFSINCL_ENV 1	/* NOBODY uses this.... */
 #define AFS_ENV                 1
+#define AFS_64BIT_CLIENT        1
 #define AFS_64BIT_ENV           1	/* Defines afs_int32 as int, not long. */
 #if defined(__ppc__)
 #define AFS_PPC_ENV		1
