@@ -34,6 +34,7 @@
 #define DARWIN_REFBASE 3
 #define AFS_WARNUSER_MARINER_ENV 1
 #define AFS_CACHE_VNODE_PATH
+#define AFS_NEW_BKG 1
 #define NEED_IOCTL32
 
 /* File system entry (used if mount.h doesn't define MOUNT_AFS */
@@ -115,7 +116,6 @@
 #define AFS_UIOSYS      UIO_SYSSPACE
 #define AFS_UIOUSER     UIO_USERSPACE
 #define AFS_CLBYTES     CLBYTES
-#define osi_GetTime(x)  microtime(x)
 #define AFS_KALLOC(x)   _MALLOC(x, M_TEMP, M_WAITOK)
 #define AFS_KFREE(x,y)  _FREE(x,M_TEMP)
 #define v_count         v_usecount
@@ -140,6 +140,7 @@
 
 #define AFS_ENV                 1
 #define AFS_64BIT_ENV           1	/* Defines afs_int32 as int, not long. */
+#define AFS_64BIT_CLIENT        1
 #if defined(__ppc__)
 #define AFS_PPC_ENV		1
 #elif defined(__i386__) || defined(__amd64__)
