@@ -14,26 +14,19 @@
 /* These two needed for rxgen output to work */
 #include <afsconfig.h>
 #include <afs/param.h>
+#include <afs/stds.h>
+#include <afs/opr.h>
 
+#include <roken.h>
 
-#include <stdio.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <errno.h>
 #ifdef AFS_NT40_ENV
-#include <winsock2.h>
 #include <afs/fs_utils.h>
 #else
-#include <unistd.h>
-#include <netinet/in.h>
 #include <afs/venus.h>
 #endif
-#include <signal.h>
-#include <afs/stds.h>
+
 #include <rx/xdr.h>
 #include <afs/prs_fs.h>
-#include <stdlib.h>
-#include <string.h>
 #include <afs/sys_prototypes.h>
 #include <afs/afs_consts.h>
 
@@ -53,6 +46,7 @@ simplify_name(char *orig_name, char *true_name)
 {
     struct stat statbuff;
 
+
 #ifdef AFS_NT40_ENV
     if (stat(orig_name, &statbuff) < 0) {
 	*true_name = '\0';
@@ -185,14 +179,12 @@ find_me(char *arg, char *parent_dir)
 	 */
 	strncpy(parent_dir, truename, bp - truename);
 	parent_dir[bp - truename] = 0;
-	bp++;			/*Skip the slash */
     } else {
 	/*
 	 * No slash appears in the given file name.  Set parent_dir to the current
 	 * directory, and the last component as the given name.
 	 */
 	strcpy(parent_dir, ".");
-	bp = truename;
     }
 
     return 1;			/* found it */
@@ -237,7 +229,7 @@ static struct Acl *
 ParseAcl(char *astr)
 {
     int nplus, nminus, i, trights;
-    char tname[MAXNAME];
+    char tname[MAXNAME + 1] = "";
     struct AclEntry *first, *last, *tl;
     struct Acl *ta;
     sscanf(astr, "%d", &nplus);
@@ -245,15 +237,15 @@ ParseAcl(char *astr)
     sscanf(astr, "%d", &nminus);
     SkipLine(astr);
 
-    ta = (struct Acl *)malloc(sizeof(struct Acl));
+    ta = malloc(sizeof(struct Acl));
     ta->nplus = nplus;
 
     last = 0;
     first = 0;
     for (i = 0; i < nplus; i++) {
-	sscanf(astr, "%100s %d", tname, &trights);
+	sscanf(astr, "%" opr_stringize(MAXNAME) "s %d", tname, &trights);
 	SkipLine(astr);
-	tl = (struct AclEntry *)malloc(sizeof(struct AclEntry));
+	tl = malloc(sizeof(struct AclEntry));
 	if (!first)
 	    first = tl;
 	strcpy(tl->name, tname);
@@ -396,8 +388,10 @@ init_child(char *myname)
      * reads from the latter, the child reads from the former, and
      * writes to the latter.
      */
-    pipe(pipe1);
-    pipe(pipe2);
+    if (pipe(pipe1) || pipe(pipe2)) {
+	using_child = 0;
+	return 0;
+    }
 
     /* fork a child */
     pid = fork();
@@ -438,7 +432,8 @@ password_bad(char *pw)
     if (using_child) {
 	fprintf(childin, "%s\n", pw);
 	fflush(childin);
-	fscanf(childout, "%d", &rc);
+	if (fscanf(childout, "%d", &rc) < 1)
+	    rc = -1;
     }
 
     return (rc);
