@@ -27,6 +27,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <afsconfig.h>
 #include <afs/param.h>
 
+#include <roken.h>
+
 #include <afs/vlserver.h>
 #include <afs/vldbint.h>
 #include <afs/volint.h>
@@ -285,11 +287,10 @@ afscp_ServerById(struct afscp_cell *thecell, afsUUID * u)
 	}
 	thecell->fsservers = newlist;
     }
-    ret = malloc(sizeof(struct afscp_server));
+    ret = calloc(1, sizeof(struct afscp_server));
     if (ret == NULL) {
 	return NULL;
     }
-    memset(ret, 0, sizeof(struct afscp_server));
     thecell->fsservers[thecell->nservers] = ret;
     memmove(&ret->id, u, sizeof(afsUUID));
     ret->cell = thecell->id;
@@ -369,17 +370,17 @@ afscp_ServerByAddr(struct afscp_cell *thecell, afs_uint32 addr)
 	else
 	    thecell->srvsalloced = 4;
 	newlist = realloc(thecell->fsservers,
-			  thecell->srvsalloced * sizeof(struct afscp_server));
+			  thecell->srvsalloced
+			      * sizeof(struct afscp_server *));
 	if (newlist == NULL) {
 	    return NULL;
 	}
 	thecell->fsservers = newlist;
     }
-    ret = malloc(sizeof(struct afscp_server));
+    ret = calloc(1, sizeof(struct afscp_server));
     if (ret == NULL) {
 	return NULL;
     }
-    memset(ret, 0, sizeof(struct afscp_server));
     thecell->fsservers[thecell->nservers] = ret;
     ret->cell = thecell->id;
     memset(&uuid, 0, sizeof(uuid));
