@@ -33,8 +33,8 @@
 int setlim(int limcon, uchar_t hard, int limit);
 #endif
 
-#ifndef AFS_ARM_LINUX20_ENV
-#if defined(AFS_S390_LINUX20_ENV)
+#ifndef AFS_ARM_LINUX_ENV
+#if defined(AFS_S390_LINUX_ENV)
 int PRE_Block;	/* Remnants of preemption support. */
 #else
 char PRE_Block;	/* Remnants of preemption support. */
@@ -52,7 +52,7 @@ char PRE_Block;	/* Remnants of preemption support. */
 #define MAXINT     (~(1<<((sizeof(int)*8)-1)))
 #define MINSTACK   44
 
-#if defined(__hp9000s800) || defined(AFS_PARISC_LINUX24_ENV)
+#if defined(__hp9000s800)
 #define MINFRAME 128
 #define STACK_ALIGN 8
 #else
@@ -365,7 +365,7 @@ LWP_CreateProcess(void *(*ep) (void *), int stacksize, int priority, void *parm,
 	Initialize_PCB(temp, priority, stackmemory, stacksize, ep, parm, name);
 	insert(temp, &runnable[priority]);
 	temp2 = lwp_cpptr;
-#if !defined(AFS_ARM_LINUX20_ENV) && !defined(AFS_ARM_DARWIN_ENV)
+#if !defined(AFS_ARM_LINUX_ENV) && !defined(AFS_ARM_DARWIN_ENV)
 	if (PRE_Block != 0)
 	    Abort_LWP("PRE_Block not 0");
 
@@ -373,10 +373,6 @@ LWP_CreateProcess(void *(*ep) (void *), int stacksize, int priority, void *parm,
 	PRE_Block = 1;
 #endif
 	lwp_cpptr = temp;
-#if defined(AFS_PARISC_LINUX24_ENV)
-	savecontext(Create_Process_Part2, &temp2->context,
-		    stackptr + MINFRAME);
-#else
 #ifdef __hp9000s800
 	savecontext(Create_Process_Part2, &temp2->context,
 		    stackptr + MINFRAME);
@@ -389,20 +385,19 @@ LWP_CreateProcess(void *(*ep) (void *), int stacksize, int priority, void *parm,
 	savecontext(Create_Process_Part2, &temp2->context, stackptr + stacksize - 16);	/* 16 = 2 * jmp_buf_type */
 #endif /* !sys_x86_darwin_80 */
 #else
-#if defined(AFS_SPARC64_LINUX20_ENV) || defined(AFS_SPARC_LINUX20_ENV)
+#if defined(AFS_SPARC64_LINUX_ENV) || defined(AFS_SPARC_LINUX_ENV)
 	savecontext(Create_Process_Part2, &temp2->context, stackptr + stacksize - 0x40);	/* lomgjmp does something
 												 * with %fp + 0x38 */
 #else
-#if defined(AFS_S390_LINUX20_ENV)
+#if defined(AFS_S390_LINUX_ENV)
 	savecontext(Create_Process_Part2, &temp2->context,
 		    stackptr + stacksize - MINFRAME);
-#else /* !AFS_S390_LINUX20_ENV */
+#else /* !AFS_S390_LINUX_ENV */
 	savecontext(Create_Process_Part2, &temp2->context,
 		    stackptr + stacksize - sizeof(void *));
-#endif /* AFS_S390_LINUX20_ENV */
-#endif /* AFS_SPARC64_LINUX20_ENV || AFS_SPARC_LINUX20_ENV */
+#endif /* AFS_S390_LINUX_ENV */
+#endif /* AFS_SPARC64_LINUX_ENV || AFS_SPARC_LINUX_ENV */
 #endif /* AFS_SGI62_ENV */
-#endif
 #endif
 	/* End of gross hack */
 
@@ -461,7 +456,7 @@ LWP_CreateProcess2(void *(*ep) (void *), int stacksize, int priority, void *parm
 	Initialize_PCB(temp, priority, stackptr, stacksize, ep, parm, name);
 	insert(temp, &runnable[priority]);
 	temp2 = lwp_cpptr;
-#if !defined(AFS_ARM_LINUX20_ENV) && !defined(AFS_ARM_DARWIN_ENV)
+#if !defined(AFS_ARM_LINUX_ENV) && !defined(AFS_ARM_DARWIN_ENV)
 	if (PRE_Block != 0)
 	    Abort_LWP("PRE_Block not 0");
 
@@ -519,19 +514,19 @@ LWP_DestroyProcess(PROCESS pid)
 	    pid->status = DESTROYED;
 	    move(pid, &runnable[pid->priority], &blocked);
 	    temp = lwp_cpptr;
-#if defined(__hp9000s800) || defined(AFS_PARISC_LINUX24_ENV)
+#if defined(__hp9000s800)
 	    savecontext(Dispatcher, &(temp->context),
 			&(LWPANCHOR.dsptchstack[MINFRAME]));
 #elif defined(AFS_SGI62_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
 	    savecontext(Dispatcher, &(temp->context),
 			&(LWPANCHOR.
 			  dsptchstack[(sizeof LWPANCHOR.dsptchstack) - 8]));
-#elif defined(AFS_SPARC64_LINUX20_ENV) || defined(AFS_SPARC_LINUX20_ENV)
+#elif defined(AFS_SPARC64_LINUX_ENV) || defined(AFS_SPARC_LINUX_ENV)
 	    savecontext(Dispatcher, &(temp->context),
 			&(LWPANCHOR.
 			  dsptchstack[(sizeof LWPANCHOR.dsptchstack) -
 				      0x40]));
-#elif defined(AFS_S390_LINUX20_ENV)
+#elif defined(AFS_S390_LINUX_ENV)
 	    savecontext(Dispatcher, &(temp->context),
 			&(LWPANCHOR.
 			  dsptchstack[(sizeof LWPANCHOR.dsptchstack) -
@@ -909,7 +904,7 @@ Dispatcher(void)
      * the guard word at the front of the stack being damaged and
      * for the stack pointer being below the front of the stack.
      * WARNING!  This code assumes that stacks grow downward. */
-#if defined(__hp9000s800) || defined(AFS_PARISC_LINUX24_ENV)
+#if defined(__hp9000s800)
     /* Fix this (stackcheck at other end of stack?) */
     if (lwp_cpptr != NULL && lwp_cpptr->stack != NULL
 	&& (lwp_cpptr->stackcheck !=
@@ -961,7 +956,7 @@ Dispatcher(void)
 	printf("Dispatch %d [PCB at 0x%x] \"%s\"\n", ++dispatch_count,
 	       runnable[i].head, runnable[i].head->name);
 #endif
-#if !defined(AFS_ARM_LINUX20_ENV) && !defined(AFS_ARM_DARWIN_ENV)
+#if !defined(AFS_ARM_LINUX_ENV) && !defined(AFS_ARM_DARWIN_ENV)
     if (PRE_Block != 1)
 	Abort_LWP("PRE_Block not 1");
 #endif
@@ -1052,7 +1047,7 @@ Initialize_PCB(PROCESS temp, int priority, char *stack, int stacksize,
     temp->index = lwp_nextindex++;
     temp->stack = stack;
     temp->stacksize = stacksize;
-#if defined(__hp9000s800) || defined(AFS_PARISC_LINUX24_ENV)
+#if defined(__hp9000s800)
     if (temp->stack != NULL)
 	temp->stackcheck = *(int *)((temp->stack) + stacksize - 4);
 #else
@@ -1107,7 +1102,7 @@ Initialize_Stack(char *stackptr, int stacksize)
 	for (i = 0; i < stacksize; i++)
 	    stackptr[i] = i & 0xff;
     else
-#if defined(__hp9000s800) || defined(AFS_PARISC_LINUX24_ENV)
+#if defined(__hp9000s800)
 	*(afs_int32 *) (stackptr + stacksize - 4) = STACKMAGIC;
 #else
 	*(afs_int32 *) stackptr = STACKMAGIC;
@@ -1120,7 +1115,7 @@ Stack_Used(char *stackptr, int stacksize)
 {
     int i;
 
-#if defined(__hp9000s800) || defined(AFS_PARISC_LINUX24_ENV)
+#if defined(__hp9000s800)
     if (*(afs_int32 *) (stackptr + stacksize - 4) == STACKMAGIC)
 	return 0;
     else {
