@@ -43,24 +43,14 @@ die "Unable to find unpacked source code\n" if !$vdir;
 
 my $srcdir = $tmpdir."/".$vdir;
 
-# Work out which version we're dealing with from the configure.ac file
+# Work out which version we're dealing with from git-version script
+# (which may use a .version file)
 my $afsversion;
 my $linuxver;
 my $linuxrel;
-my $fh = new IO::File $srcdir."/configure.ac"
-  or die "Unable to find unpacked configure.ac file";
-while(<$fh>) {
-  next if (/^\s*\#/);
-
-  if (/AM_INIT_AUTOMAKE\(openafs,(.*)\)/) {
-    $afsversion = $1;
-    next;
-  }
-}
-undef $fh;
 
 if (not defined($afsversion)) {
-  $afsversion = `"$srcdir/build-tools/git-version" "$srcdir"`;
+  $afsversion = `"/bin/sh" "$srcdir/build-tools/git-version" "$srcdir"`;
 }
 
 # Build the Linux version and release information from the package version
@@ -128,13 +118,12 @@ while (defined($file = $pkgdirh->read)) {
 }
 undef $dirh;
 
-# Some files need particular modes.
-chmod 0755, $tmpdir."/rpmdir/SOURCES/openafs-kernel-version.sh";
+# This file needs particular modes.
 chmod 0755, $tmpdir."/rpmdir/SOURCES/openafs-kvers-is.sh";
 
 # Create the specfile. Use sed for this, cos its easier
 system("cat ".$srcdir."/src/packaging/RedHat/openafs.spec.in | ".
-       "sed -e 's/\@VERSION\@/$afsversion/g' ".
+       "sed -e 's/\@PACKAGE_VERSION\@/$afsversion/g' ".
        "    -e 's/\@LINUX_PKGVER\@/$linuxver/g' ".
        "    -e 's/\@LINUX_PKGREL\@/$linuxrel/g' ".
        "    -e 's/\%define afsvers.*/%define afsvers $afsversion/g' ".
