@@ -47,20 +47,16 @@
  */
 
 #if defined(KERNEL) && !defined(UKERNEL)
-#if !defined(AFS_LINUX26_ENV)
+#if !defined(AFS_LINUX_ENV)
 #include <sys/param.h>
 #endif
-#ifdef AFS_LINUX20_ENV
+#ifdef AFS_LINUX_ENV
 #include "h/string.h"
-#if 0
-#define bzero(A,C) memset((A), 0, (C))
-#endif
 #else
 #include <sys/systm.h>
 #endif
 #else
-#include <stdio.h>
-#include <string.h>
+#include <roken.h>
 #endif
 #include "xdr.h"
 
