@@ -6,14 +6,11 @@
  * License.  For details, see the LICENSE file in the top-level source
  * directory or online at http://www.openafs.org/dl/license10.html
  */
-
 #include <afsconfig.h>
 #include <afs/param.h>
 
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <sys/file.h>
-#include <stdio.h>
+#include <roken.h>
+
 
 #include "AFS_component_version_number.c"
 
