@@ -9,25 +9,15 @@
 
 #include <afsconfig.h>
 #include <afs/param.h>
-
-
 #include <afs/stds.h>
-#include <sys/types.h>
-#ifdef AFS_NT40_ENV
-#include <winsock2.h>
-#include <afsutil.h>
-#else
-#include <sys/file.h>
-#include <netdb.h>
-#include <netinet/in.h>
-#endif
-#include <time.h>
-#include <stdio.h>
-#include <string.h>
+
+#include <roken.h>
+
 #include <rx/xdr.h>
 #include <rx/rx.h>
 #include <lock.h>
 #include <afs/afsutil.h>
+
 #include "ubik.h"
 #include "utst_int.h"
 
@@ -328,9 +318,6 @@ main(int argc, char **argv)
     }
 
     sc[0] = rxnull_NewServerSecurityObject();
-#if 0
-    sc[1] = rxvab_NewServerSecurityObject("applexx", 0);
-#endif
     tservice = rx_NewService(0, USER_SERVICE_ID, "Sample", sc, 1 /*2 */ ,
 			     SAMPLE_ExecuteRequest);
     if (tservice == (struct rx_service *)0) {
