@@ -18,18 +18,16 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-
-#include "uss_kauth.h"		/*Module interface */
-#include "uss_common.h"		/*Common defs & operations */
-#include <errno.h>
-#include <pwd.h>
-
-#include <string.h>
+#include <roken.h>
 
 #include <afs/com_err.h>
 #include <afs/kautils.h> /*MAXKTCREALMLEN*/
 #include <afs/kaport.h>		/* pack_long */
 #include <afs/kauth.h>
+
+#include "uss_kauth.h"		/*Module interface */
+#include "uss_common.h"		/*Common defs & operations */
+
 #define uss_kauth_MAX_SIZE	2048
 #undef USS_KAUTH_DB
 /*
@@ -643,7 +641,7 @@ uss_kauth_SetFields(char *username, char *expirestring, char *reuse,
 	fprintf(stderr, "Zero represents unlimited login attempts.\n");
 	fprintf(stderr, "Continuing with limit == 254 for user %s.\n",
 		username);
-	misc_auth_bytes[2] = 255;
+	misc_auth_bytes[2] = 0xff;
     } else
 	misc_auth_bytes[2] = nfailures + 1;
 
