@@ -10,18 +10,13 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
+#include <roken.h>
+#include <afs/opr.h>
 
-#include <sys/types.h>
-#include <stdio.h>
-#include <time.h>
 #include <ctype.h>
-#ifdef AFS_NT40_ENV
-#include <malloc.h>
-#endif
-#include <string.h>
-#include <stdlib.h>
-#include "afsutil.h"
 
+#include <afs/opr.h>
+#include "afsutil.h"
 #include "ktime.h"
 
 /* some date parsing routines */
@@ -42,10 +37,8 @@ static char *day[] = {
 };
 
 /* free token list returned by parseLine */
-#ifdef undef
-static
-LocalFreeTokens(alist)
-     struct token *alist;
+static void
+LocalFreeTokens(struct token *alist)
 {
     struct token *nlist;
     for (; alist; alist = nlist) {
@@ -53,9 +46,8 @@ LocalFreeTokens(alist)
 	free(alist->key);
 	free(alist);
     }
-    return 0;
+    return;
 }
-#endif
 
 static int
 space(int x)
@@ -85,10 +77,9 @@ LocalParseLine(char *aline, struct token **alist)
 	    if (inToken) {
 		inToken = 0;	/* end of this token */
 		*tptr++ = 0;
-		ttok = (struct token *)malloc(sizeof(struct token));
+		ttok = malloc(sizeof(struct token));
 		ttok->next = NULL;
-		ttok->key = (char *)malloc(strlen(tbuffer) + 1);
-		strcpy(ttok->key, tbuffer);
+		ttok->key = strdup(tbuffer);
 		if (last) {
 		    last->next = ttok;
 		    last = ttok;
@@ -256,11 +247,11 @@ ktime_ParsePeriodic(char *adate, struct ktime *ak)
 	/* look at each token */
 	if (strcmp(tt->key, "now") == 0) {
 	    ak->mask |= KTIME_NOW;
-	    return 0;
+	    goto out;
 	}
 	if (strcmp(tt->key, "never") == 0) {
 	    ak->mask |= KTIME_NEVER;
-	    return 0;
+	    goto out;
 	}
 	if (strcmp(tt->key, "at") == 0)
 	    continue;
@@ -269,14 +260,17 @@ ktime_ParsePeriodic(char *adate, struct ktime *ak)
 	if (isdigit(tt->key[0])) {
 	    /* parse a time */
 	    code = ParseTime(ak, tt->key);
-	    if (code)
-		return -1;
+	    if (code) {
+		code = -1;
+		goto out;
+	    }
 	    continue;
 	}
 	/* otherwise use keyword table */
 	for (tp = ptkeys;; tp++) {
 	    if (tp->key == NULL) {
-		return -1;
+		code = -1;
+		goto out;
 	    }
 	    if (strcmp(tp->key, tt->key) == 0)
 		break;
@@ -291,23 +285,31 @@ ktime_ParsePeriodic(char *adate, struct ktime *ak)
 	    /* am or pm token */
 	    if ((tp->value & 0xff) == 1) {
 		/* pm */
-		if (!(ak->mask & KTIME_HOUR))
-		    return -1;
-		if (ak->hour < 12)
+		if (!(ak->mask & KTIME_HOUR)) {
+		    code = -1;
+		    goto out;
+		}
+		if (ak->hour < 12) {
 		    ak->hour += 12;
 		/* 12 is 12 PM */
-		else if (ak->hour != 12)
-		    return -1;
+		} else if (ak->hour != 12) {
+		    code = -1;
+		    goto out;
+		}
 	    } else {
 		/* am is almost a noop, except that we map 12:01 am to 0:01 */
-		if (ak->hour > 12)
-		    return -1;
+		if (ak->hour > 12) {
+		    code = -1;
+		    goto out;
+		}
 		if (ak->hour == 12)
 		    ak->hour = 0;
 	    }
 	}
     }
-    return 0;
+out:
+    LocalFreeTokens(tt);
+    return code;
 }
 
 /* ktime_DisplayString
@@ -636,12 +638,6 @@ ktime_InterpretDate(struct ktime_date * akdate)
 	temp = tresult + tbit;	/* see if adding this bit keeps us < akdate */
 	tsp = localtime(&temp);
 	tsp->tm_mon++;
-#ifdef notdef
-	if (tsp->tm_mon == 0) {
-	    tsp->tm_mon = 12;
-	    tsp->tm_year--;
-	}
-#endif
 	if (KDateCmp(akdate, tsp) >= 0) {
 	    /* if temp still represents earlier than date than we're searching
 	     * for, add in bit as increment, otherwise use old value and look
