@@ -2024,13 +2024,17 @@ _namei_examine_special(char * path1,
 	 * this like a normal file, we won't try to INC or DEC it. */
 	info.linkCount = 0;
     } else {
-	char path2[512];
+	char *path2;
 	/* Open this handle */
-	snprintf(path2, sizeof(path2),
-		 "%s" OS_DIRSEP "%s", path1, dname);
+	if (asprintf(&path2, "%s" OS_DIRSEP "%s", path1, dname) < 0) {
+	    Log("_namei_examine_special: memory allocation failure\n");
+	    ret = -1;
+	    goto error;
+	}
 	linkHandle->fd_fd = OS_OPEN(path2, Testing ? O_RDONLY : O_RDWR, 0666);
 	info.linkCount =
 	    namei_GetLinkCount(linkHandle, (Inode) 0, 1, 1, Testing);
+	free(path2);
     }
 
     if (!judgeFun ||
@@ -3271,19 +3275,17 @@ namei_ConvertROtoRWvolume(char *pname, VolumeId volumeId)
     return code;
 }
 
-/* PrintInode
+/**
+ * Format a string to print inode numbers.
  *
- * returns a static string used to print either 32 or 64 bit inode numbers.
+ * @param[out]  s    string buffer
+ * @param[in]   ino  inode number
+ * @returns pointer to formatted inode number string
  */
 char *
-PrintInode(char *s, Inode ino)
+PrintInode(afs_ino_str_t s, Inode ino)
 {
-    static afs_ino_str_t result;
-    if (!s)
-	s = result;
-
     snprintf(s, sizeof(afs_ino_str_t), "%llu", (afs_uintmax_t) ino);
-
     return s;
 }
 
